@@ -24,7 +24,7 @@ macro_rules! deprecate_msg {
         "This function is deprecated. Please use Rest::request instead."
     };
 }
-
+#[derive(Debug, Clone)]
 pub struct Rest {
     secret: Option<String>,
     client: Client,
@@ -138,7 +138,7 @@ impl Rest {
         /*
         let response: String = self
             .client
-            .request(method, url)
+            .request(R::METHOD, url)
             .query(&params)
             .headers(headers)
             .body(body)
