@@ -23,7 +23,7 @@ impl Default for OrderType {
     }
 }
 
-#[derive(Copy, Clone, Debug, Deserialize, PartialEq)]
+#[derive(Copy, Clone, Debug, Deserialize, Serialize, PartialEq)]
 #[serde(rename_all = "camelCase")]
 /// Represents the status of the order.
 /// However, the REST and websockets APIs assign these values differently.
@@ -75,7 +75,7 @@ impl Default for Side {
     }
 }
 
-#[derive(Copy, Clone, Debug, Deserialize, PartialEq)]
+#[derive(Copy, Clone, Debug, Deserialize, Serialize, PartialEq)]
 #[serde(rename_all = "camelCase")]
 pub enum FutureType {
     Future,
@@ -91,9 +91,10 @@ pub enum DepositStatus {
     Unconfirmed,
     Cancelled,
     Complete,
+    Initiated,
 }
 
-#[derive(Copy, Clone, Debug, Deserialize, PartialEq)]
+#[derive(Copy, Clone, Debug, Deserialize, Serialize, PartialEq)]
 #[serde(rename_all = "camelCase")]
 pub enum MarketType {
     Future,
@@ -103,7 +104,7 @@ pub enum MarketType {
 /// Returned by GET /positions.
 /// See https://docs.ftx.com/#get-positions.
 
-#[derive(Clone, Debug, Deserialize)]
+#[derive(Clone, Debug, Deserialize, Serialize)]
 #[serde(rename_all = "camelCase")]
 pub struct Position {
     pub cost: Decimal,
@@ -123,11 +124,96 @@ pub struct Position {
     pub collateral_used: Decimal,
 }
 
-#[derive(Copy, Clone, Debug, Deserialize, PartialEq)]
+#[derive(Copy, Clone, Debug, Deserialize, Serialize, PartialEq)]
 #[serde(rename_all = "camelCase")]
 pub enum WithdrawStatus {
     Requested,
     Processing,
+    Sent,
     Complete,
     Cancelled,
 }
+
+#[derive(Copy, Clone, Debug)]
+pub enum Resolution {
+    FifteenSeconds,
+    Minute,
+    FiveMinutes,
+    FifteenMinutes,
+    Hour,
+    FourHours,
+    Day,
+    TwoDays,
+    ThreeDays,
+    FourDays,
+    FiveDays,
+    SixDays,
+    Week,
+    EightDays,
+    NineDays,
+    TenDays,
+    ElevenDays,
+    TwelveDays,
+    ThirteenDays,
+    FourteenDays,
+    FifteenDays,
+    SixteenDays,
+    SeventeenDays,
+    EighteenDays,
+    NineteenDays,
+    TwentyDays,
+    TwentyOneDays,
+    TwentyTwoDays,
+    TwentyThreeDays,
+    TwentyFourDays,
+    TwentyFiveDays,
+    TwentySixDays,
+    TwentySevenDays,
+    TwentyEightDays,
+    TwentyNineDays,
+    ThirtyDays,
+}
+
+impl Resolution {
+    pub fn get_seconds(&self) -> u32 {
+        match self {
+            Resolution::FifteenSeconds => 15,
+            Resolution::Minute => 60,
+            Resolution::FiveMinutes => 300,
+            Resolution::FifteenMinutes => 900,
+            Resolution::Hour => 3600,
+            Resolution::FourHours => 14400,
+            Resolution::Day => 86400,
+            Resolution::TwoDays => 86400 * 2,
+            Resolution::ThreeDays => 86400 * 3,
+            Resolution::FourDays => 86400 * 4,
+            Resolution::FiveDays => 86400 * 5,
+            Resolution::SixDays => 86400 * 6,
+            Resolution::Week => 86400 * 7,
+            Resolution::EightDays => 86400 * 8,
+            Resolution::NineDays => 86400 * 9,
+            Resolution::TenDays => 86400 * 10,
+            Resolution::ElevenDays => 86400 * 11,
+            Resolution::TwelveDays => 86400 * 12,
+            Resolution::ThirteenDays => 86400 * 13,
+            Resolution::FourteenDays => 86400 * 14,
+            Resolution::FifteenDays => 86400 * 15,
+            Resolution::SixteenDays => 86400 * 16,
+            Resolution::SeventeenDays => 86400 * 17,
+            Resolution::EighteenDays => 86400 * 18,
+            Resolution::NineteenDays => 86400 * 19,
+            Resolution::TwentyDays => 86400 * 20,
+            Resolution::TwentyOneDays => 86400 * 21,
+            Resolution::TwentyTwoDays => 86400 * 22,
+            Resolution::TwentyThreeDays => 86400 * 23,
+            Resolution::TwentyFourDays => 86400 * 24,
+            Resolution::TwentyFiveDays => 86400 * 25,
+            Resolution::TwentySixDays => 86400 * 26,
+            Resolution::TwentySevenDays => 86400 * 27,
+            Resolution::TwentyEightDays => 86400 * 28,
+            Resolution::TwentyNineDays => 86400 * 29,
+            // 30 days is not the same as 1 month, named it so to avoid confusion (eg feb can have 28 or 29 days)
+            Resolution::ThirtyDays => 86400 * 30,
+        }
+    }
+}
