@@ -1,4 +1,4 @@
-use super::common::{Coin, Id, MarketType, Side, Symbol};
+use super::common::{Coin, Id, MarketType, Resolution, Side, Symbol};
 use super::Request;
 use chrono::{DateTime, Utc};
 use http::Method;
@@ -6,7 +6,7 @@ use rust_decimal::Decimal;
 use serde::{Deserialize, Serialize};
 use std::borrow::Cow;
 
-#[derive(Clone, Debug, Deserialize)]
+#[derive(Clone, Debug, Deserialize, Serialize)]
 #[serde(rename_all = "camelCase")]
 pub struct Market {
     #[serde(rename = "type")]
@@ -16,15 +16,15 @@ pub struct Market {
     pub base_currency: Option<Coin>,
     pub quote_currency: Option<Coin>,
     pub enabled: bool,
-    pub ask: Decimal,
-    pub bid: Decimal,
+    pub ask: Option<Decimal>,
+    pub bid: Option<Decimal>,
     pub last: Option<Decimal>,
     pub post_only: bool,
     pub price_increment: Decimal,
     pub size_increment: Decimal,
     pub restricted: bool,
     pub min_provide_size: Decimal,
-    pub price: Decimal,
+    pub price: Option<Decimal>, // Sometimes, there is no price available?
     pub high_leverage_fee_exempt: bool,
     pub change1h: Decimal,
     pub change24h: Decimal,
@@ -116,7 +116,7 @@ impl Request for GetOrderBook {
     }
 }
 
-#[derive(Copy, Clone, Debug, Deserialize)]
+#[derive(Copy, Clone, Debug, Deserialize, Serialize)]
 #[serde(rename_all = "camelCase")]
 pub struct Trade {
     pub id: Id,
@@ -128,7 +128,6 @@ pub struct Trade {
 }
 
 #[derive(Debug, Clone, Serialize, Default)]
-#[serde(rename_all = "camelCase")]
 pub struct GetTrades {
     #[serde(skip_serializing)]
     pub market_name: String,
@@ -153,6 +152,21 @@ impl GetTrades {
             ..Default::default()
         }
     }
+    // User can specify limit, start_time, and end_time.
+    // If none, use Option::None as parameter.
+    pub fn new_paged(
+        market_name: &str,
+        limit: Option<u32>,
+        start_time: Option<DateTime<Utc>>,
+        end_time: Option<DateTime<Utc>>,
+    ) -> Self {
+        Self {
+            market_name: market_name.into(),
+            limit,
+            start_time,
+            end_time,
+        }
+    }
 }
 
 impl Request for GetTrades {
@@ -169,7 +183,7 @@ impl Request for GetTrades {
 
 #[derive(Copy, Clone, Debug, Deserialize)]
 #[serde(rename_all = "camelCase")]
-pub struct Price {
+pub struct Candle {
     pub close: Decimal,
     pub high: Decimal,
     pub low: Decimal,
@@ -179,7 +193,6 @@ pub struct Price {
 }
 
 #[derive(Debug, Clone, Serialize, Default)]
-#[serde(rename_all = "camelCase")]
 pub struct GetHistoricalPrices {
     #[serde(skip_serializing)]
     pub market_name: String,
@@ -199,13 +212,30 @@ pub struct GetHistoricalPrices {
 }
 
 impl GetHistoricalPrices {
-    pub fn new(market_name: &str, resolution: u32) -> Self {
+    pub fn new(market_name: &str, resolution: Resolution) -> Self {
         Self {
             market_name: market_name.into(),
-            resolution,
+            resolution: resolution.get_seconds(),
             ..Default::default()
         }
     }
+    // User can specify limit, start_time, and end_time.
+    // If none, use Option::None as parameter.
+    pub fn new_paged(
+        market_name: &str,
+        resolution: Resolution,
+        limit: Option<u32>,
+        start_time: Option<DateTime<Utc>>,
+        end_time: Option<DateTime<Utc>>,
+    ) -> Self {
+        Self {
+            market_name: market_name.into(),
+            resolution: resolution.get_seconds(),
+            limit,
+            start_time,
+            end_time,
+        }
+    }
 }
 
 impl Request for GetHistoricalPrices {
@@ -213,7 +243,7 @@ impl Request for GetHistoricalPrices {
     const PATH: &'static str = "/markets/{}/candles";
     const AUTH: bool = false;
 
-    type Response = Vec<Price>;
+    type Response = Vec<Candle>;
 
     fn path(&self) -> Cow<'_, str> {
         Cow::Owned(format!("/markets/{}/candles", self.market_name))
