@@ -1,24 +1,27 @@
 mod account;
 mod common;
+mod fills;
 mod futures;
 mod markets;
 mod orders;
 mod positions;
+mod spot_margin;
 mod subaccounts;
 mod wallet;
 
 pub use self::account::*;
 pub use self::common::*;
+pub use self::fills::*;
 pub use self::futures::*;
 pub use self::markets::*;
 pub use self::orders::*;
 pub use self::positions::*;
+pub use self::spot_margin::*;
 pub use self::subaccounts::*;
 pub use self::wallet::*;
 
 use chrono::{DateTime, Utc};
 use http::Method;
-use rust_decimal::prelude::*;
 use serde::Serializer;
 use serde::{de::DeserializeOwned, ser::Error, Deserialize, Serialize};
 use std::borrow::Cow;
@@ -49,18 +52,6 @@ pub struct ErrorResponse {
 
 // REST API -> Markets
 
-#[derive(Copy, Clone, Debug, Deserialize)]
-#[serde(rename_all = "camelCase")]
-pub struct FutureStats {
-    pub volume: Decimal,
-    pub next_funding_rate: Decimal,
-    pub next_funding_time: DateTime<Utc>,
-    pub expiration_price: Decimal,
-    pub predicted_expiration_price: Decimal,
-    pub strike_price: Decimal,
-    pub open_interest: Decimal,
-}
-
 pub fn serialize_as_timestamp<S>(
     dt: &Option<DateTime<Utc>>,
     serializer: S,
