@@ -4,6 +4,7 @@ use chrono::{DateTime, Utc};
 use http::Method;
 use rust_decimal::prelude::*;
 use serde::{Deserialize, Serialize};
+use std::borrow::Cow;
 
 #[derive(Clone, Debug, Deserialize)]
 #[serde(rename_all = "camelCase")]
@@ -30,7 +31,7 @@ pub struct WalletBalance {
 pub struct WalletDeposit {
     pub id: Id,
     pub coin: String,
-    pub size: Decimal,
+    pub size: Option<Decimal>,
     pub time: String,
     pub status: DepositStatus,
     pub confirmations: Option<usize>,
@@ -80,6 +81,7 @@ impl Request for GetWalletBalances {
 #[derive(Debug, Clone, Serialize, Default)]
 #[serde(rename_all = "camelCase")]
 pub struct GetWalletDepositAddress {
+    #[serde(skip_serializing)]
     pub coin: String,
     pub method: Option<String>,
 }
@@ -106,6 +108,10 @@ impl Request for GetWalletDepositAddress {
     const AUTH: bool = true;
 
     type Response = WalletDepositAddress;
+
+    fn path(&self) -> Cow<'_, str> {
+        Cow::Owned(format!("/wallet/deposit_address/{}", self.coin))
+    }
 }
 
 #[derive(Clone, Debug, Deserialize)]
@@ -154,7 +160,7 @@ pub struct WalletWithdrawal {
     pub coin: String,
     pub size: Decimal,
     pub time: String,
-    pub address: String,
+    pub address: Option<String>, // `None` for transfers between sub-accounts
     pub status: WithdrawStatus,
     pub fee: Option<Decimal>, // fee, not included in size
     pub txid: Option<String>,
@@ -186,3 +192,23 @@ impl Request for GetWalletWithdrawals {
 
     type Response = Vec<WalletWithdrawal>;
 }
+
+#[derive(Debug, Clone, Serialize, Default)]
+#[serde(rename_all = "camelCase")]
+pub struct RequestWithdrawal {
+    pub coin: String,
+    pub size: Decimal,
+    pub address: String,
+    pub tag: Option<String>,
+    pub method: Option<String>,
+    pub password: Option<String>,
+    pub code: Option<String>,
+}
+
+impl Request for RequestWithdrawal {
+    const METHOD: Method = Method::POST;
+    const PATH: &'static str = "/wallet/withdrawals";
+    const AUTH: bool = true;
+
+    type Response = WalletWithdrawal;
+}
